==> deepin-update-ui_1.0.5.tar.xz: BUILD/src/dcc-update-plugin/translations/update_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name>CheckUpdate</name>
    <message>
        <source>Last check: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NoActive</name>
    <message>
        <source>Your system is not activated, and it failed to connect to update services</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateHistory</name>
    <message>
        <source>Settings will be reverted in %1s.</source>
        <translation>Os atopos volverán a ser os do sistema en %1s.</translation>
    </message>
    <message>
        <source>Save the display settings?</source>
        <translation>Gardar os atopos de visualización？</translation>
    </message>
    <message>
        <source>Revert</source>
        <translation>Devolver</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gardar</translation>
    </message>
</context>
<context>
    <name>UpdateList</name>
    <message>
        <source>View Details</source>
        <translation>Ver detalles</translation>
    </message>
    <message>
        <source>Updates:</source>
        <translation>Actualizacions:</translation>
    </message>
    <message>
        <source>Release time:</source>
        <translation>Hora de lanzamento:</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Colapsar</translation>
    </message>
</context>
<context>
    <name>UpdateLogHelper</name>
    <message>
        <source>NONE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LOW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MEDIUM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HIGH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CRITICAL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>critical-risk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>high-risk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>medium-risk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>low-risk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This update fixes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>vulnerabilities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>vulnerability</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 of %2 %3</source>
        <translation type="unfinished"></translation>
        <extra-content_explain>`数字+%`会在代码中替换为字符串，例如：3 of high-risk vulnerabilities；各语言需要根据实际情况增加空格(例如：中文没有空格，英文有空格)</extra-content_explain>
    </message>
    <message>
        <source>, </source>
        <translation type="unfinished"></translation>
        <extra-content_explain>中文逗号不需要空格，英文逗号需要空格For more details, please visit</extra-content_explain>
    </message>
    <message>
        <source>for more details, please visit </source>
        <translation type="unfinished"></translation>
        <extra-content_explain>这句话后面会带上一个超链接，各语言自行决定末尾需不需要加空格</extra-content_explain>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Checking for updates, please wait…</source>
        <translation>Buscando actualizacions, agúarde un momento…</translation>
    </message>
    <message>
        <source>Your system is up to date</source>
        <translation>Sua sistema está actualizado</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation type="unfinished">Erro descoñecido</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please free up %1 disk space first.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dependency error, failed to detect the updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please check your network and try again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading updates failed. Please check your network and try again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insufficient disk space</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File missing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Service connection is abnormal, please check the network and try again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The repository source configuration is not valid, please check and try again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check Again</source>
        <translation type="unfinished">Comprobar de novo</translation>
    </message>
</context>
<context>
    <name>UpdateSetting</name>
    <message>
        <source>Smart Mirror Switch</source>
        <translation>Intercambiador de espeiro inteligente</translation>
    </message>
    <message>
        <source>Update Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Function Updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and  security updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Third-party Updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delivers  updates for additional repository sources</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Advanced Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Limit Speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Limit Setting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto Download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enabling &quot;Auto Download Updates&quot; will automatically download updates when connected to the internet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download when Inactive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start at</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End at</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Updates Notification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear Package Cache</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View</source>
        <translation type="unfinished">Ver
</translation>
    </message>
    <message>
        <source>Join Internal Testing Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Join the internal testing channel to get deepin latest updates</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>System Updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fixed some known bugs and security vulnerabilities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Third-party Repositories</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>update</name>
    <message>
        <source>System Update</source>
        <translation>Actualización do sistema</translation>
    </message>
    <message>
        <source>System update and upgrade</source>
        <translation>Actualización e actualización de software</translation>
    </message>
</context>
<context>
    <name>updateMain</name>
    <message>
        <source>Update Settings</source>
        <translation>Configuración das actualizacións</translation>
    </message>
    <message>
        <source>Update installation successful</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>To ensure proper functioning of your system and applications, please restart your computer after the update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reboot now</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Installation update failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue Update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Installing updates...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Installing</source>
        <translation type="unfinished">Instalando</translation>
    </message>
    <message>
        <source>Update download completed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Install updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update size: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update download failed</source>
        <translation type="unfinished">Fallou a descarga da actualización</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading updates...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Updates Available</source>
        <translation type="unfinished">Disponibles actualizacions</translation>
    </message>
    <message>
        <source>Download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Backing up in progress...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Backing up in progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure Update settings、Security Updates、Auto Download Updates and Updates Notification</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.6.tar.xz: BUILD/src/dcc-update-plugin/translations/update_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name>CheckUpdate</name>
    <message>
        <source>Last check: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NoActive</name>
    <message>
        <source>Your system is not activated, and it failed to connect to update services</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QuitTestingChannelDialog</name>
    <message>
        <source>If you exit the beta program, you will no longer receive beta updates.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateHistoryDialog</name>
    <message>
        <source>Save the display settings?</source>
        <translation type="unfinished">Gardar os atopos de visualización？</translation>
    </message>
    <message>
        <source>Settings will be reverted in %1s.</source>
        <translation type="unfinished">Os atopos volverán a ser os do sistema en %1s.</translation>
    </message>
    <message>
        <source>Revert</source>
        <translation type="unfinished">Devolver</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished">Gardar</translation>
    </message>
</context>
<context>
    <name>UpdateList</name>
    <message>
        <source>View Details</source>
        <translation>Ver detalles</translation>
    </message>
    <message>
        <source>Updates:</source>
        <translation>Actualizacions:</translation>
    </message>
    <message>
        <source>Release time:</source>
        <translation>Hora de lanzamento:</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Colapsar</translation>
    </message>
</context>
<context>
    <name>UpdateLogHelper</name>
    <message>
        <source>NONE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LOW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MEDIUM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HIGH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CRITICAL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>critical-risk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>high-risk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>medium-risk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>low-risk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This update fixes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>vulnerabilities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>vulnerability</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 of %2 %3</source>
        <translation type="unfinished"></translation>
        <extra-content_explain>`数字+%`会在代码中替换为字符串，例如：3 of high-risk vulnerabilities；各语言需要根据实际情况增加空格(例如：中文没有空格，英文有空格)</extra-content_explain>
    </message>
    <message>
        <source>, </source>
        <translation type="unfinished"></translation>
        <extra-content_explain>中文逗号不需要空格，英文逗号需要空格For more details, please visit</extra-content_explain>
    </message>
    <message>
        <source>for more details, please visit </source>
        <translation type="unfinished"></translation>
        <extra-content_explain>这句话后面会带上一个超链接，各语言自行决定末尾需不需要加空格</extra-content_explain>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Checking for updates, please wait…</source>
        <translation>Buscando actualizacions, agúarde un momento…</translation>
    </message>
    <message>
        <source>Your system is up to date</source>
        <translation>Sua sistema está actualizado</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation type="unfinished">Erro descoñecido</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please free up %1 disk space first.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dependency error, failed to detect the updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please check your network and try again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading updates failed. Please check your network and try again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insufficient disk space</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File missing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Service connection is abnormal, please check the network and try again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The repository source configuration is not valid, please check and try again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check Again</source>
        <translation type="unfinished">Comprobar de novo</translation>
    </message>
</context>
<context>
    <name>UpdateSetting</name>
    <message>
        <source>Smart Mirror Switch</source>
        <translation>Intercambiador de espeiro inteligente</translation>
    </message>
    <message>
        <source>Update Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Function Updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and  security updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Third-party Updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delivers  updates for additional repository sources</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Advanced Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Limit Speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Limit Setting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto Download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enabling &quot;Auto Download Updates&quot; will automatically download updates when connected to the internet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download when Inactive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start at</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End at</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Updates Notification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear Package Cache</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View</source>
        <translation type="unfinished">Ver
</translation>
    </message>
    <message>
        <source>Join Internal Testing Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Join the internal testing channel to get deepin latest updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Click here to complete the application</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>System Updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fixed some known bugs and security vulnerabilities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Third-party Repositories</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>update</name>
    <message>
        <source>System Update</source>
        <translation>Actualización do sistema</translation>
    </message>
    <message>
        <source>System update and upgrade</source>
        <translation>Actualización e actualización de software</translation>
    </message>
</context>
<context>
    <name>updateMain</name>
    <message>
        <source>Update Settings</source>
        <translation>Configuración das actualizacións</translation>
    </message>
    <message>
        <source>Update installation successful</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>To ensure proper functioning of your system and applications, please restart your computer after the update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reboot now</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Installation update failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue Update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Installing updates...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Installing</source>
        <translation type="unfinished">Instalando</translation>
    </message>
    <message>
        <source>Update download completed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Install updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update size: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update download failed</source>
        <translation type="unfinished">Fallou a descarga da actualización</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading updates...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Updates Available</source>
        <translation type="unfinished">Disponibles actualizacions</translation>
    </message>
    <message>
        <source>Download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Backing up in progress...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Backing up in progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure Update settings、Security Updates、Auto Download Updates and Updates Notification</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
